FrontierHook class

The FrontierHook class is used to authenticate requests using strategies.

Constructors

FrontierHook(List<Strategy<StrategyOptions>> strategies, {void onError([Exception? exception])?})
Create a new instance of FrontierHook.

Properties

hashCode int
The hash code for this object.
no setterinherited
onError → void Function([Exception? exception])?
The onError function to be called when an error occurs.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
service Frontier
The Hook can expose a service that will be used by the application without the need to create a new module.
no setter
strategies List<Strategy<StrategyOptions>>
The strategies to be used.
final

Methods

beforeHandle(ExecutionContext<ArgumentsHost> context) Future<void>
The beforeHandle method is used to execute code before the request is handled
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited