GuardMeta class

The GuardMeta class is used to define the strategy to be used.

Constructors

GuardMeta(String strategy)
Create a new instance of GuardMeta.

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
The name property contains the name of the metadata.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
The value property contains the value of the metadata.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited