StrategyRequest class final

The StrategyRequest class represents a request that is passed to a strategy

It is useful to have a common interface for all strategies to use

Constructors

StrategyRequest({Map<String, String> headers = const {}, Map<String, String> query = const {}, dynamic body, Map<String, String> cookies = const {}})
Creates a new StrategyRequest
const

Properties

body → dynamic
The body of the request
final
cookies Map<String, String>
The cookies of the request
final
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, String>
The headers of the request
final
query Map<String, String>
The query parameters of the request
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited