Strategy<T extends StrategyOptions> class
abstract
Base class to extend for creating a new strategy
Constructors
-
Strategy(T options, StrategyCallback<
T, Object> callback) - Creates a new Strategy
Properties
-
callback
→ StrategyCallback<
T, Object> -
The callback to call when the strategy is done
final
- done → void Function(Object? result)
-
The callback to call when the strategy is done
no setter
-
future
→ Future<
Object?> -
The future of the strategy
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
Name of the strategy
no setter
- options → T
-
The options for the strategy
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
authenticate(
StrategyRequest request) → Future< void> - Authenticate the request
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reset(
) → void - Reset the strategy
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited